@@ -10,6 +10,9 @@ from faker.providers.person.en import Provider
 import numpy as np
 import pandas as pd
 
+GB = 1024 * 1024 * 1024
+MB = 1024 * 1024
+
 
 def pytest_addoption(parser):
     """
@@ -238,6 +241,11 @@ def get_good_meta_data(connector):
     return meta
 
 
+@pytest.fixture(scope="session")
+def batch_size():
+    return 2.5 * MB
+
+
 def random_names(name_type, size):
     """
     Generate n-length ndarray of person names.
@@ -276,7 +284,7 @@ def random_numbers(start, end, size):
 
 
 @pytest.fixture(scope="session")
-def five_column_dataset():
+def five_column_100_row_dataset():
     size = 100
     df = pd.DataFrame(columns=['First', 'Last', 'Gender', 'Birthdate'])
     df['First'] = random_names('first_names', size)
@@ -287,6 +295,18 @@ def five_column_dataset():
     return to_dc_format(df)
 
 
+@pytest.fixture(scope="session", params=[1, 10, 100, 1000])
+def load_data():
+    size = 100
+    df = pd.DataFrame(columns=['First', 'Last', 'Gender', 'Birthdate'])
+    df['First'] = random_names('first_names', size)
+    df['Last'] = random_names('last_names', size)
+    df['Gender'] = random_genders(size)
+    df['BirthDate'] = random_dates(start=pd.to_datetime('1940-01-01'), end=pd.to_datetime('2022-01-01'), size=size)
+    df['StartDate'] = random_dates(start=pd.to_datetime('1940-01-01'), end=pd.to_datetime('2022-01-01'), size=size)
+    print(sys.getsizeof(to_dc_format(df)))
+
+
 @pytest.fixture(scope="session")
 def mapping_object():
     return [
