@@ -356,7 +356,8 @@ class TestGetData:
 
     @pytest.mark.source
     @pytest.mark.get_data
-    def test_filters_by_yesterday_returns(self, good_object_id, get_three_good_field_ids, connector, filtered_column_nm):
+    def test_filters_by_yesterday_returns(self, good_object_id, get_three_good_field_ids, connector,
+                                          filtered_column_nm):
         connector.authenticate()
         data = connector.get_data(good_object_id,
                                   get_three_good_field_ids,
@@ -373,13 +374,13 @@ class TestGetData:
     @pytest.mark.source
     @pytest.mark.get_data
     def test_filters_by_yesterday_works(self,
-                                    good_object_id,
-                                    get_three_good_field_ids,
-                                    connector,
-                                    filtered_column_nm,
-                                    filtered_column_date_format,
-                                    custom_date_start_val,
-                                    custom_date_end_val):
+                                        good_object_id,
+                                        get_three_good_field_ids,
+                                        connector,
+                                        filtered_column_nm,
+                                        filtered_column_date_format,
+                                        custom_date_start_val,
+                                        custom_date_end_val):
         if filtered_column_nm not in get_three_good_field_ids:
             get_three_good_field_ids.append(filtered_column_nm)
         connector.authenticate()
@@ -427,16 +428,15 @@ class TestGetData:
         for row in data["data"]:
             assert datetime.strptime(row[filtered_column_nm], filtered_column_date_format) < end
 
-
     @pytest.mark.source
     @pytest.mark.get_data
     def test_filters_no_end_selection(self,
-                                        good_object_id,
-                                        get_three_good_field_ids,
-                                        connector,
-                                        filtered_column_nm,
-                                        filtered_column_date_format,
-                                        custom_date_start_val):
+                                      good_object_id,
+                                      get_three_good_field_ids,
+                                      connector,
+                                      filtered_column_nm,
+                                      filtered_column_date_format,
+                                      custom_date_start_val):
         if filtered_column_nm not in get_three_good_field_ids:
             get_three_good_field_ids.append(filtered_column_nm)
         connector.authenticate()
@@ -491,9 +491,9 @@ class TestGetMetaData:
 class TestLoadData:
     @pytest.mark.destination
     @pytest.mark.load_data
-    def test_load_data_append(self, connector, good_object_id, mapping_object, _append, five_column_dataset):
+    def test_load_data_append(self, connector, good_object_id, mapping_object, _append, five_column_100_row_dataset):
         try:
-            connector.load_data(five_column_dataset,
+            connector.load_data(five_column_100_row_dataset,
                                 good_object_id,
                                 mapping_object,
                                 _append,
@@ -504,9 +504,9 @@ class TestLoadData:
 
     @pytest.mark.destination
     @pytest.mark.load_data
-    def test_load_data_replace(self, connector, good_object_id, mapping_object, _replace, five_column_dataset):
+    def test_load_data_replace(self, connector, good_object_id, mapping_object, _replace, five_column_100_row_dataset):
         try:
-            connector.load_data(five_column_dataset,
+            connector.load_data(five_column_100_row_dataset,
                                 good_object_id,
                                 mapping_object,
                                 _replace,
@@ -522,9 +522,9 @@ class TestLoadData:
                                         bad_object_id,
                                         mapping_object,
                                         _replace,
-                                        five_column_dataset):
+                                        five_column_100_row_dataset):
         # FIXME: a potential issue here is that i do not have object name validation for "_bad" on an object_id
-        connector.load_data(five_column_dataset,
+        connector.load_data(five_column_100_row_dataset,
                             bad_object_id,
                             mapping_object,
                             _replace,
@@ -534,3 +534,21 @@ class TestLoadData:
         objects = connector.get_objects()
         assert bad_object_id in [obj["object_id"] for obj in objects]
 
+    @pytest.mark.destination
+    @pytest.mark.load_data
+    def test_load_large_data(self,
+                             connector,
+                             good_object_id,
+                             mapping_object,
+                             _replace,
+                             five_column_dataset):
+        # FIXME: a potential issue here is that i do not have object name validation for "_bad" on an object_id
+        connector.load_data(five_column_dataset,
+                            good_object_id,
+                            mapping_object,
+                            _replace,
+                            batch_number=1,
+                            total_batches=1)
+        connector.authenticate()
+        objects = connector.get_objects()
+        assert bad_object_id in [obj["object_id"] for obj in objects]
